pub struct MemoryAPIHandler { /* private fields */ }Expand description
An API handler for reporting the memory bounds and usage of all components.
This handler exposes a single route – /memory/status – which returns the overall bounds and live usage of each
registered component.