pub struct ComponentRegistryHandle { /* private fields */ }Expand description
A cloneable, read-only handle to a component registry.
This handle provides access to read-only operations such as creating an API handler or verifying bounds. Unlike
ComponentRegistry, it can be freely cloned and shared across ownership boundaries.
Obtained via ComponentRegistry::root.
Implementations
Sourceimpl ComponentRegistryHandle
impl ComponentRegistryHandle
Sourcepub fn verify_bounds(
&self,
initial_grant: MemoryGrant,
) -> Result<VerifiedBounds, VerifierError>
pub fn verify_bounds( &self, initial_grant: MemoryGrant, ) -> Result<VerifiedBounds, VerifierError>
Validates that all components are able to respect the calculated effective limit.
If validation succeeds, VerifiedBounds is returned, which provides information about the effective limit that
can be used for allocating memory.
Errors
A number of invalid conditions are checked and will cause an error to be returned:
- when a component has invalid bounds (for example, minimum required bytes higher than firm limit)
- when the combined total of the firm limit for all components exceeds the effective limit
Sourcepub fn api_handler(&self) -> MemoryAPIHandler
pub fn api_handler(&self) -> MemoryAPIHandler
Gets an API handler for reporting the memory bounds and usage of all component in the registry.
This handler exposes routes for querying the memory bounds and usage of all registered components. See
MemoryAPIHandler for more information about routes and responses.
Sourcepub fn as_bounds(&self) -> ComponentBounds
pub fn as_bounds(&self) -> ComponentBounds
Gets the total minimum required bytes for all components in the registry.
See ComponentRegistry::as_bounds for more details.